%% Reading of data files and application of corrections for laser scans without water and with standing water.

fig_switch = 0;
z_pos = 400;
ymid = 364; % optical middle of laser scanner, using determine_optical_middle.m

file_path_dry = '~/Documents/abstracts_papers/PAPER1_laser_scanner/polystyrene_experiment/0164_data/bottom0607_z550_10runs/bottom0607_z550_10runs.%d.dat';
files_dry = [0:9];
                        
StartOfSwipes = [1 752 1503 2254]+50; % row number in input file for 'Correctie_withoutwater' where a new swipe starts (or where you want it to start)
EndOfSwipes = [751 1502 2253 3003]-50;

global ZR550 L_laser_camera refraction_index y_measure;

ZR550 = (550 - z_pos) + 609; % measured distance H (mm) between bottom of flume and focal point of laser (at y-location specified by y_measure)
y_measure = 500;
L_laser_camera = 175; % mm distance between laser and camera
refraction_index = 1.33; % refraction index of water devided by refraction index of air

%%%% only needed in case 'sandbed' %%%%
directory_input = '~/Documents/abstracts_papers/PAPER2_lab/experiments_LTD/ExpD2/laser_scanner/still';
range = {1}; % file numbers of data files to read for sandbed case
ind_dry = [1]; % the item in the list 'range' that is a dry bed

xx = [1.7,3.7,6,8.3,11.3];
z0 = -58.4;
x0 = 0;
S0 = 0;
if length(range)>length(ind_dry)
    % 'WL' is water level time series over time span 'time'; size(WL) = (length(time),8)
    h = mean(WL(datenum(time)>=datenum(2018,7,2,13,39,46.18)&datenum(time)<=datenum(2018,7,2,14,14,10.31),[8 7 6 4 3]));
else
    h = z0;
end
Mlist = ZR550 - h + z0 + (xx - x0)*S0;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% either choose to manually give AE_fit and coef values, or calculate them
% with Inlezen_withoutwater_vs550_real.m and Correctie_withoutwater_real.m
AE_fit = [0 0 0];
coef = [0 0 47.35];
% [withoutwater,zwithoutwater] = Inlezen_withoutwater_vs550_real(file_path_dry,files_dry,1);
% [nowater_a,AE,coef,AE_fit,nowater_a_original] = Correctie_withoutwater_real(zwithoutwater,fig_switch,0,StartOfSwipes,EndOfSwipes);
% optional arguments:   1) degree (degree of polynomial for flume bottom fitting); default 2
%                       2) degreeAE (degree of polynomial for residual error fitting); default 2
%                       3) skip_in_AE_fit (number of lines from flume wall to skip (in first and last swipe); default [15 15]                 
coef(3) = coef(3)+(z_pos-400);

[bedprofile,names] = Inlezen_sandbed_1tot99_real(directory_input, range, 0);
[bedprofile_corr] = Refractie_correctie_sandbed_1tot99_real(coef,AE_fit,Mlist,xx,bedprofile,ind_dry,ymid);
       
% if scanning of all swipes is in one direction (so v/v turned off in laser scanner software), include these lines before plotting (probably change numbers to define row-bounds of second and fourth swipe):
%         bedprofile_corr{1}(17253:end,:) = flipud(bedprofile_corr{1}(17253:end,:));
%         bedprofile_corr{1}(17254:end,:) = flipud(bedprofile_corr{1}(17254:end,:));
%%%%%%
        y_offset = 2968.2;
        X = cell(size(bedprofile_corr));
        Y = X;
        val = X;
        XI = X;
        YI = X;
        VI = X;
        for i=1:length(bedprofile_corr)
            bedprofile_corr{i}(:,148:end) = ZR550-bedprofile_corr{i}(:,148:end);
            z_dum = bedprofile_corr{i}(:,148:end);
            z_dum(z_dum<=0 & z_dum>=350) = NaN;
            bedprofile_corr{i}(:,148:end) = z_dum;
            clearvars z_dum
            X{i} = zeros(size(bedprofile_corr{i},1),144);
            for j=1:144
                X{i}(:,j) = bedprofile_corr{i}(:,1)/1000;
            end
            bedprofile_corr{i}(:,4:147) = -bedprofile_corr{i}(:,4:147)+y_offset;
            Y{i} = bedprofile_corr{i}(:,4:147);
            val{i} = bedprofile_corr{i}(:,148:291);
            if fig_switch==1
                makefigure(17,4);
                fig{i} = pcolor(X{i},Y{i},val{i});
                set(fig{i},'LineStyle','none');
                set(gca,'ticklabelInterpreter','latex');
                hc = colorbar;
                set(hc,'ticklabelinterpreter','latex');
                ylabel(hc,'$z\ (\mathrm{mm})$','interpreter','latex');
                xlabel('$x\ (\mathrm{m})$','interpreter','latex');
                ylabel('$y\ (\mathrm{mm})$','interpreter','latex');
                set(gca,'Xdir','reverse');
                set(gca,'Ydir','reverse');
                ylim([0 2600]);
                caxis([120 320]);
                printfigure('~/Desktop/testfigures/laser_scanner','raster','cmyk');
            end
        end
        
        for i=1:length(bedprofile_corr)
              [XI{i},YI{i},VI{i}] = grid_and_loess(0,4,0,bedprofile_corr,i,0,350,0.00002/2.5,1,2,1,12,8); %f=0.00002 for dx=5mm
        end

end
